/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.it;

import org.jdtaus.core.container.ContainerInitializer;
import org.jdtaus.core.container.Dependency;
import org.jdtaus.core.container.Implementation;
import org.jdtaus.core.container.ModelFactory;
import org.jdtaus.core.container.Properties;
import org.jdtaus.core.container.Property;

/**
 * Implementation used for testing the {@code Container} runtime.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: TestImplementation.java 3210 2007-04-29 21:36:10Z schulte2005 $
 */
public class TestImplementation
    implements TestSpecification, ContainerInitializer
{
    //--Implementation----------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /** Meta-data describing the implementation. */
    private static final Implementation META =
        ModelFactory.getModel().getModules().
        getImplementation(TestImplementation.class.getName());

    //----------------------------------------------------------Implementation--
    //--Constructors------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /**
     * Protected <code>TestImplementation</code> implementation constructor.
     *
     * @param meta Implementation meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    protected TestImplementation(final Implementation meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }
    /**
     * Protected <code>TestImplementation</code> dependency constructor.
     *
     * @param meta dependency meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    protected TestImplementation(final Dependency meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }

    /**
     * Initializes the properties of the instance.
     *
     * @param meta the property values to initialize the instance with.
     *
     * @throws NullPointerException if {@code meta} is {@code null}.
     */
    protected void initializeProperties(final Properties meta)
    {
        Property p;

        if(meta == null)
        {
            throw new NullPointerException("meta");
        }

        p = meta.getProperty("stringObject");
        this._stringObject = (java.lang.String) p.getValue();


        p = meta.getProperty("shortObject");
        this._shortObject = (java.lang.Short) p.getValue();


        p = meta.getProperty("longObject");
        this._longObject = (java.lang.Long) p.getValue();


        p = meta.getProperty("integerObject");
        this._integerObject = (java.lang.Integer) p.getValue();


        p = meta.getProperty("floatObject");
        this._floatObject = (java.lang.Float) p.getValue();


        p = meta.getProperty("doubleObject");
        this._doubleObject = (java.lang.Double) p.getValue();


        p = meta.getProperty("characterObject");
        this._characterObject = (java.lang.Character) p.getValue();


        p = meta.getProperty("byteObject");
        this._byteObject = (java.lang.Byte) p.getValue();


        p = meta.getProperty("booleanObject");
        this._booleanObject = (java.lang.Boolean) p.getValue();


        p = meta.getProperty("short");
        this._short = ((java.lang.Short) p.getValue()).shortValue();


        p = meta.getProperty("long");
        this._long = ((java.lang.Long) p.getValue()).longValue();


        p = meta.getProperty("int");
        this._int = ((java.lang.Integer) p.getValue()).intValue();


        p = meta.getProperty("float");
        this._float = ((java.lang.Float) p.getValue()).floatValue();


        p = meta.getProperty("double");
        this._double = ((java.lang.Double) p.getValue()).doubleValue();


        p = meta.getProperty("char");
        this._char = ((java.lang.Character) p.getValue()).charValue();


        p = meta.getProperty("byte");
        this._byte = ((java.lang.Byte) p.getValue()).byteValue();


        p = meta.getProperty("boolean");
        this._boolean = ((java.lang.Boolean) p.getValue()).booleanValue();

    }

    //------------------------------------------------------------Constructors--
    //--ContainerInitializer----------------------------------------------------

    /** Flag indicating that the {@link #initialize()} method got called. */
    private boolean initialized;

    public void initialize()
    {
        this.initialized = true;
    }

    //----------------------------------------------------ContainerInitializer--
    //--Dependencies------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.


    //------------------------------------------------------------Dependencies--
    //--Properties--------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /**
     * Property {@code stringObject}.
     * @serial
     */
    private java.lang.String _stringObject;

    /**
     * Gets the value of property <code>stringObject</code>.
     *
     * @return the value of property <code>stringObject</code>.
     */
    protected java.lang.String getStringObject()
    {
        return this._stringObject;
    }

    /**
     * Property {@code shortObject}.
     * @serial
     */
    private java.lang.Short _shortObject;

    /**
     * Gets the value of property <code>shortObject</code>.
     *
     * @return the value of property <code>shortObject</code>.
     */
    protected java.lang.Short getShortObject()
    {
        return this._shortObject;
    }

    /**
     * Property {@code longObject}.
     * @serial
     */
    private java.lang.Long _longObject;

    /**
     * Gets the value of property <code>longObject</code>.
     *
     * @return the value of property <code>longObject</code>.
     */
    protected java.lang.Long getLongObject()
    {
        return this._longObject;
    }

    /**
     * Property {@code integerObject}.
     * @serial
     */
    private java.lang.Integer _integerObject;

    /**
     * Gets the value of property <code>integerObject</code>.
     *
     * @return the value of property <code>integerObject</code>.
     */
    protected java.lang.Integer getIntegerObject()
    {
        return this._integerObject;
    }

    /**
     * Property {@code floatObject}.
     * @serial
     */
    private java.lang.Float _floatObject;

    /**
     * Gets the value of property <code>floatObject</code>.
     *
     * @return the value of property <code>floatObject</code>.
     */
    protected java.lang.Float getFloatObject()
    {
        return this._floatObject;
    }

    /**
     * Property {@code doubleObject}.
     * @serial
     */
    private java.lang.Double _doubleObject;

    /**
     * Gets the value of property <code>doubleObject</code>.
     *
     * @return the value of property <code>doubleObject</code>.
     */
    protected java.lang.Double getDoubleObject()
    {
        return this._doubleObject;
    }

    /**
     * Property {@code characterObject}.
     * @serial
     */
    private java.lang.Character _characterObject;

    /**
     * Gets the value of property <code>characterObject</code>.
     *
     * @return the value of property <code>characterObject</code>.
     */
    protected java.lang.Character getCharacterObject()
    {
        return this._characterObject;
    }

    /**
     * Property {@code byteObject}.
     * @serial
     */
    private java.lang.Byte _byteObject;

    /**
     * Gets the value of property <code>byteObject</code>.
     *
     * @return the value of property <code>byteObject</code>.
     */
    protected java.lang.Byte getByteObject()
    {
        return this._byteObject;
    }

    /**
     * Property {@code booleanObject}.
     * @serial
     */
    private java.lang.Boolean _booleanObject;

    /**
     * Gets the value of property <code>booleanObject</code>.
     *
     * @return the value of property <code>booleanObject</code>.
     */
    protected java.lang.Boolean isBooleanObject()
    {
        return this._booleanObject;
    }

    /**
     * Property {@code short}.
     * @serial
     */
    private short _short;

    /**
     * Gets the value of property <code>short</code>.
     *
     * @return the value of property <code>short</code>.
     */
    protected short getShort()
    {
        return this._short;
    }

    /**
     * Property {@code long}.
     * @serial
     */
    private long _long;

    /**
     * Gets the value of property <code>long</code>.
     *
     * @return the value of property <code>long</code>.
     */
    protected long getLong()
    {
        return this._long;
    }

    /**
     * Property {@code int}.
     * @serial
     */
    private int _int;

    /**
     * Gets the value of property <code>int</code>.
     *
     * @return the value of property <code>int</code>.
     */
    protected int getInt()
    {
        return this._int;
    }

    /**
     * Property {@code float}.
     * @serial
     */
    private float _float;

    /**
     * Gets the value of property <code>float</code>.
     *
     * @return the value of property <code>float</code>.
     */
    protected float getFloat()
    {
        return this._float;
    }

    /**
     * Property {@code double}.
     * @serial
     */
    private double _double;

    /**
     * Gets the value of property <code>double</code>.
     *
     * @return the value of property <code>double</code>.
     */
    protected double getDouble()
    {
        return this._double;
    }

    /**
     * Property {@code char}.
     * @serial
     */
    private char _char;

    /**
     * Gets the value of property <code>char</code>.
     *
     * @return the value of property <code>char</code>.
     */
    protected char getChar()
    {
        return this._char;
    }

    /**
     * Property {@code byte}.
     * @serial
     */
    private byte _byte;

    /**
     * Gets the value of property <code>byte</code>.
     *
     * @return the value of property <code>byte</code>.
     */
    protected byte getByte()
    {
        return this._byte;
    }

    /**
     * Property {@code boolean}.
     * @serial
     */
    private boolean _boolean;

    /**
     * Gets the value of property <code>boolean</code>.
     *
     * @return the value of property <code>boolean</code>.
     */
    protected boolean isBoolean()
    {
        return this._boolean;
    }


    //--------------------------------------------------------------Properties--
    //--TestSpecification-------------------------------------------------------

    public boolean isInitialized()
    {
        return this.initialized;
    }

    //-------------------------------------------------------TestSpecification--
}
